==================================
Computer Programming for Beginners
==================================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTUXdYTnRaTy1LLVE>`__

